List:Internals« Previous MessageNext Message »
From:lenz Date:July 15 2005 7:24am
Subject:bk commit into 5.0 tree (lenz:1.1936)
View as plain text  
Below is the list of changes that have just been committed into a local
5.0 repository of lenz. When lenz does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet
  1.1936 05/07/15 09:23:36 lenz@stripped +2 -0
  Merge mysql.com:/space/my/mysql-4.1.13-clone
  into mysql.com:/space/my/mysql-5.0-build

  support-files/mysql.spec.sh
    1.106 05/07/15 09:23:29 lenz@stripped +0 -0
    Auto merged

  sql/sql_prepare.cc
    1.137 05/07/15 09:23:29 lenz@stripped +0 -0
    Auto merged

# This is a BitKeeper patch.  What follows are the unified diffs for the
# set of deltas contained in the patch.  The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User:	lenz
# Host:	metis.lenznet
# Root:	/space/my/mysql-5.0-build/RESYNC

--- 1.136/sql/sql_prepare.cc	2005-07-14 13:27:14 +02:00
+++ 1.137/sql/sql_prepare.cc	2005-07-15 09:23:29 +02:00
@@ -313,24 +313,28 @@
 
 static void set_param_float(Item_param *param, uchar **pos, ulong len)
 {
+  float data;
 #ifndef EMBEDDED_LIBRARY
   if (len < 4)
     return;
-#endif
-  float data;
   float4get(data,*pos);
+#else
+  data= *(float*) *pos;
+#endif
   param->set_double((double) data);
   *pos+= 4;
 }
 
 static void set_param_double(Item_param *param, uchar **pos, ulong len)
 {
+  double data;
 #ifndef EMBEDDED_LIBRARY
   if (len < 8)
     return;
-#endif
-  double data;
   float8get(data,*pos);
+#else
+  data= *(double*) *pos;
+#endif
   param->set_double((double) data);
   *pos+= 8;
 }
Thread
bk commit into 5.0 tree (lenz:1.1936)lenz15 Jul
--- 1.105/support-files/mysql.spec.sh	2005-07-04 22:14:12 +02:00
+++ 1.106/support-files/mysql.spec.sh	2005-07-15 09:23:29 +02:00
@@ -440,19 +440,20 @@
 	/sbin/chkconfig --add mysql
 fi
 
-# Create a MySQL user. Do not report any problems if it already
-# exists. This is redhat specific and should be handled more portable
-useradd -M -r -d $mysql_datadir -s /bin/bash -c "MySQL server" %{mysqld_user} 2> /dev/null || true 
+# Create a MySQL user and group. Do not report any problems if it already
+# exists.
+groupadd -r -c "MySQL server" %{mysqld_user} 2> /dev/null || true
+useradd -M -r -d $mysql_datadir -s /bin/bash -c "MySQL server" -g %{mysqld_user} %{mysqld_user} 2> /dev/null || true 
 
 # Change permissions so that the user that will run the MySQL daemon
 # owns all database files.
-chown -R %{mysqld_user} $mysql_datadir
+chown -R %{mysqld_user}:%{mysqld_user} $mysql_datadir
 
 # Initiate databases
 %{_bindir}/mysql_install_db --rpm --user=%{mysqld_user}
 
 # Change permissions again to fix any new files.
-chown -R %{mysqld_user} $mysql_datadir
+chown -R %{mysqld_user}:%{mysqld_user} $mysql_datadir
 
 # Fix permissions for the permission database so that only the user
 # can read them.
@@ -667,6 +668,11 @@
 # itself - note that they must be ordered by date (important when
 # merging BK trees)
 %changelog 
+* Fri Jul 15 2005 Lenz Grimmer <lenz@stripped>
+
+- create a "mysql" user group and assign the mysql user account to that group
+  in the server postinstall section. (BUG 10984)
+
 * Tue Jun 14 2005 Lenz Grimmer <lenz@stripped>
 
 - Do not build statically on i386 by default, only when adding either "--with
